@@ -10,9 +10,6 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import os
-
-from nose.tools import assert_equal
 from ibm_botocore.session import Session
 from tests import ClientHTTPStubber
 from tests.functional import TEST_MODELS_DIR
@@ -56,21 +53,19 @@ def test_old_model_continues_to_work():
                      'Content-Type': 'application/x-amz-json-1.1'},
             body=b'{"CertificateSummaryList":[]}')
         response = client.list_certificates()
-        assert_equal(
-            response,
-            {'CertificateSummaryList': [],
-             'ResponseMetadata': {
-                 'HTTPHeaders': {
-                     'content-length': '29',
-                     'content-type': 'application/x-amz-json-1.1',
-                     'date': 'Fri, 26 Oct 2018 01:46:30 GMT',
-                     'x-amzn-requestid': 'abcd'},
-                 'HTTPStatusCode': 200,
-                 'RequestId': 'abcd',
-                 'RetryAttempts': 0}
-             }
-        )
+        assert response == {
+            'CertificateSummaryList': [],
+            'ResponseMetadata': {
+                'HTTPHeaders': {
+                    'content-length': '29',
+                    'content-type': 'application/x-amz-json-1.1',
+                    'date': 'Fri, 26 Oct 2018 01:46:30 GMT',
+                    'x-amzn-requestid': 'abcd'},
+                'HTTPStatusCode': 200,
+                'RequestId': 'abcd',
+                'RetryAttempts': 0}
+        }
 
     # Also verify we can use the paginators as well.
-    assert_equal(client.can_paginate('list_certificates'), True)
-    assert_equal(client.waiter_names, ['certificate_validated'])
+    assert client.can_paginate('list_certificates') is True
+    assert client.waiter_names == ['certificate_validated']
